@@ -113,7 +113,7 @@ class _Regressor(object):
                                          None)
 
             if callable(sample_predictions):
-                pred = sample_predictions(data.format_data(),
+                pred = sample_predictions(data,
                                           regress_limit=regress_limit,
                                           output_type=output_type)
             else:
@@ -148,6 +148,7 @@ class _Regressor(object):
                   regress_limit=None,
                   output_type='mean',
                   use_weights=False,
+                  adjust=True,
                   return_summary=True):
         """
         Find out how well the training samples fit the model
@@ -156,6 +157,7 @@ class _Regressor(object):
         :param param_dict: Paramters dictionary for _Regressor child class
         :param n_folds: Number of folds to compute results for
         :param use_weights: If weights should be used for model fit/training
+        :param adjust: If the gain and bias should be adjusted
         :param return_summary: IF summary should be returned or non-summarized results
         :param output_type: Metric to be omputed from the random forest (options: 'mean','median','sd')
         :param regress_limit: List of upper and lower regression limits for training fit prediction
@@ -172,6 +174,12 @@ class _Regressor(object):
             regressor.fit_data(trn_data.format_data(),
                                use_weights=use_weights)
 
+            get_adjustment_param = getattr(regressor, 'get_adjustment_param', None)
+
+            if adjust and (get_adjustment_param is not None) and callable(get_adjustment_param):
+                get_adjustment_param(data_limits=regress_limit,
+                                     output_type=output_type)
+
             pred = regressor.sample_predictions(test_data.format_data(),
                                                 regress_limit=regress_limit,
                                                 output_type=output_type)
@@ -180,12 +188,20 @@ class _Regressor(object):
         if not return_summary:
             return results
         else:
-            return {'rsq_mean': np.mean([result['rsq'] for result in results]),
-                    'rsq_sd': np.std([result['rsq'] for result in results]),
-                    'rmse_mean': np.mean([result['rmse'] for result in results]),
-                    'rmse_sd': np.std([result['rmse'] for result in results]),
-                    'split_rsq': [result['rsq'] for result in results],
-                    'split_rmse': [result['rmse'] for result in results]}
+            _output = {'rsq_mean': np.mean([result['rsq'] for result in results]),
+                       'rsq_sd': np.std([result['rsq'] for result in results]),
+                       'rmse_mean': np.mean([result['rmse'] for result in results]),
+                       'rmse_sd': np.std([result['rmse'] for result in results]),
+                       'slope_mean': np.mean([result['slope'] for result in results]),
+                       'slope_sd': np.std([result['slope'] for result in results]),
+                       'intercept_mean': np.mean([result['intercept'] for result in results]),
+                       'intercept_sd': np.std([result['intercept'] for result in results])}
+
+            for fold_indx in range(n_folds):
+                _output.update({'rsq_fold_{}'.format(fold_indx + 1): results[fold_indx]['rsq']})
+                _output.update({'rmse_fold_{}'.format(fold_indx + 1): results[fold_indx]['rmse']})
+
+            return _output
 
     def grid_search_param(self,
                           data,
@@ -348,8 +364,8 @@ class _Regressor(object):
                        raster_obj,
                        outfile=None,
                        outdir=None,
-                       output_type=None,
-                       band_name=None,
+                       output_type='mean',
+                       band_name='band_1',
                        **kwargs):
         """
         Tree variance from the RF regressor
@@ -390,9 +406,6 @@ class _Regressor(object):
         defaults = _Regressor.get_defaults(raster=raster_obj,
                                            **kwargs)
 
-        output_type = defaults['output_type'] if output_type is None else output_type
-        band_name = defaults['band_name'] if band_name is None else band_name
-
         verbose = defaults['verbose'] if 'verbose' in defaults else False
         defaults['verbose'] = False
 
@@ -736,8 +749,8 @@ class MRegressor(_Regressor):
         lm = self.linear_regress(data['labels'], y)
 
         return {
-            'pred_y': y,
-            'obs_y': data['labels'],
+            'pred': y,
+            'labels': data['labels'],
             'rmse': rmse,
             'rsq': lm['rsq'],
             'slope': lm['slope'],
@@ -1197,8 +1210,8 @@ class RFRegressor(_Regressor):
         """
         Get tree predictions from the RF regressor
         :param data: Dictionary object from Samples.format_data
-        :param output_type: Metric to be computed from RandomForestRegressor. List of options or a single option.
-                            (options: 'mean','median','sd', 'var','full')
+        :param output_type: Metric to be computed from RandomForestRegressor.
+                           (options: 'mean','median','sd', 'var','full')
         :param kwargs: Keyword arguments:
                'gain': Adjustment of the predicted output by linear adjustment of gain (slope)
                'bias': Adjustment of the predicted output by linear adjustment of bias (intercept)
@@ -1226,43 +1239,32 @@ class RFRegressor(_Regressor):
         else:
             regress_limit = None
 
-        if type(output_type) not in (tuple, list):
-            output_type = [output_type]
-
-        mean_prediction = self.predict(data['features'],
-                                       output_type='mean',
-                                       verbose=verbose)
+        prediction = self.predict(data['features'],
+                                  output_type=output_type,
+                                  verbose=verbose)
 
         if regress_limit is not None:
             lm = self.linear_regress(data['labels'],
-                                     mean_prediction,
+                                     prediction,
                                      xlim=regress_limit)
         else:
             lm = self.linear_regress(data['labels'],
-                                     mean_prediction)
+                                     prediction)
 
-        rmse = sqrt(mean_squared_error(data['labels'], mean_prediction))
+        rmse = sqrt(mean_squared_error(data['labels'], prediction))
 
         # if outfile and pickle file are not provided,
         # then only return values
         out_dict = {
-            'pred_y': mean_prediction,
-            'obs_y': data['labels'],
+            'pred': prediction,
+            'labels': data['labels'],
             'rmse': rmse,
             'rsq': lm['rsq'],
             'slope': lm['slope'],
             'intercept': lm['intercept'],
         }
-
-        for output_type_elem in output_type:
-            if output_type_elem != 'mean':
-                out_dict[output_type_elem] = self.predict(data['features'],
-                                                          output_type=output_type_elem,
-                                                          verbose=verbose)
         return out_dict
 
-
-
     def get_adjustment_param(self,
                              data_limits=None,
                              output_type='mean',
@@ -1349,11 +1351,11 @@ class HRFRegressor(RFRegressor):
                        raster_obj,
                        outfile=None,
                        outdir=None,
-                       band_name=None,
-                       output_type=None,
+                       band_name='band_1',
+                       output_type='mean',
                        array_multiplier=1.0,
                        array_additive=0.0,
-                       out_data_type=None,
+                       out_data_type=gdal.GDT_Float32,
                        nodatavalue=None,
                        **kwargs):
 
@@ -1372,11 +1374,6 @@ class HRFRegressor(RFRegressor):
         :returns: Output as raster object
         """
 
-        defaults = self.get_defaults()
-        output_type = defaults['output_type'] if output_type is None else output_type
-        band_name = defaults['band_name'] if band_name is None else band_name
-        out_data_type = defaults['out_data_type'] if out_data_type is None else out_data_type
-
         self.feature_index = list(list(raster_obj.bnames.index(feat) for feat in feat_grp)
                                   for feat_grp in self.features)
 
@@ -1394,7 +1391,7 @@ class HRFRegressor(RFRegressor):
 
     def predict(self,
                 arr,
-                output_type=None,
+                output_type='mean',
                 **kwargs):
         """
         Calculate random forest model prediction, variance, or standard deviation.
@@ -1432,8 +1429,6 @@ class HRFRegressor(RFRegressor):
 
         :return: 1d image array (that will need reshaping if image output)
         """
-        defaults = self.get_defaults()
-        output_type = defaults['output_type'] if output_type is None else output_type
 
         if output_type == 'full':
             raise ValueError('Output type "full" is not supported for this class')
@@ -1446,7 +1441,7 @@ class HRFRegressor(RFRegressor):
                      arr,
                      tile_start=None,
                      tile_end=None,
-                     output_type=None,
+                     output_type='mean',
                      nodatavalue=None,
                      intvl=None,
                      min_variance=None,
@@ -1487,15 +1482,9 @@ class HRFRegressor(RFRegressor):
         :return: numpy 1-D array
         """
 
-        defaults = _Regressor.get_defaults()
-        output_type = defaults['output_type'] if output_type is None else output_type
-
         # leaf variance limit for sd or var output type
         if min_variance is None:
-            if intvl is not None:
-                min_variance = (1 - intvl/100.) * np.min(arr.astype(np.float32))
-            else:
-                min_variance = defaults['variance_limit'] * np.min(arr.astype(np.float32))
+            min_variance = 0.025 * (self.data['labels'].max() - self.data['labels'].min())
 
         # define input array shape param
         if tile_end is None:
